import Modal from "@/components/Provider/Modal";
import { css } from "@linaria/core";
import { Button, Checkbox, Form, Input, Select } from "ant-design-vue";
import { defineComponent, onMounted, reactive, ref } from "vue";
import { any } from "vue-types";
import UploadImage from "./UploadImage";
import { uploader } from "../objects";
import loading from "@/components/Provider/Loading";
const layout = {
  wrapperCol: { span: 24 },
};

export default defineComponent({
  props: {
    data: any(),
  },
  setup(props) {
    const modal = Modal.use();
    const formState: { [name: string]: any } = reactive({
      formData: {
        ...{
          name: "",
          cover: "",
          sort: 0,
          type: "list",
          isHome: false,
        },
        ...props.data,
      },
    });

    onMounted(() => {});

    const rules = reactive({
      name: [{ required: true, message: "名称不能为空", trigger: "change" }],
      cover: [{ required: false }],
      isHome: [{ required: false }],
      type: [{ required: true, message: "分类", trigger: "change" }],
    });

    const { validate, validateInfos } = Form.useForm(formState.formData, rules);

    function submit() {
      validate().then(async () => {
        await uploader.uploadBlobImages(formState.formData, {
          onProgress() {
            loading.show("上传中");
          },
        });
        loading.hidden();
        modal.submit(formState.formData);
      });
    }
    const changeBanner = (v: string) => {
      formState.formData.cover = v;
    };

    return () => {
      return (
        <div class={EditStyle}>
          <div class={"edit_content"}>
            <div class={"form_content"}>
              <Form {...layout} class={EditFormStyle} onSubmit={submit}>
                <Form.Item {...validateInfos.cover}>
                  <UploadImage
                    data={formState.formData.cover}
                    text={"上传分类banner图"}
                    onChange={changeBanner}
                  ></UploadImage>
                </Form.Item>
                <Form.Item {...validateInfos.name} label={"分类名称"}>
                  <Input
                    placeholder={"请输入分类名称"}
                    v-model={[formState.formData.name, "value"]}
                    maxlength={30}
                  />
                </Form.Item>
                <Form.Item {...validateInfos.type} label={"分类类型"}>
                  <Select v-model={[formState.formData.type, "value"]}>
                    <Select.Option value="list">列表</Select.Option>
                    <Select.Option value="detail">详情</Select.Option>
                    <Select.Option value="download">下载</Select.Option>
                  </Select>
                </Form.Item>
                <Form.Item {...validateInfos.isHome} label={"是否首页展示"}>
                  <Checkbox
                    v-model={[formState.formData.isHome, "checked"]}
                  ></Checkbox>
                </Form.Item>
                <Form.Item
                  style={{ marginBottom: 0 }}
                  wrapperCol={{ span: 24 }}
                >
                  <Button type="primary" htmlType="submit" block>
                    保存
                  </Button>
                </Form.Item>
              </Form>
            </div>
          </div>
        </div>
      );
    };
  },
});
const EditStyle = css`
  width: 400px;
  .edit_content {
    display: flex;
    flex-direction: column;
    height: 100%;
  }
  .comp_content {
    flex: 1;
    height: 0;
    overflow: hidden;

    .ant-tabs {
      height: 100%;
      .ant-tabs-nav {
        .ant-tabs-nav-wrap {
          overflow-x: auto;
        }
      }
      .ant-tabs-tab {
        user-select: none;
      }
      .ant-tabs-content {
        height: 100%;
        overflow-y: hidden;
      }
    }
  }
`;
const CompTabPane = css`
  height: 100%;
`;
const EditFormStyle = css`
  .thumb {
    width: 180px;
    height: 180px;
  }
  .updatime {
    margin-bottom: 24px;
    font-size: 12px;
  }
`;
